@@ -10,6 +10,13 @@
 @function :  
 '''
 # here put the import lib
-
+import calibration 
 def description():
     print('thank you for installing our package!')
+def camera_calibration(a,b,c):
+    d = calibration.real_calibration(a,b,c)
+    print("output from realcalibration is : ",d)
+
+if __name__ == "__main__":
+    camera_calibration(1,2,3)
+
